#ifndef FONTCLOCK_H
#define FONTCLOCK_H

#include <QWidget>
//#include <QLabel>

class FontClock : public QWidget
{
    Q_OBJECT
public:
    explicit FontClock(QColor &aColor, QString &aFormat, QFont &aFont, int aBlink1, int aBlink2, QWidget *parent = 0);

public slots:
    void showTime();

private:
//    void showTime();
    void calcFontSize();

protected:
    void paintEvent(QPaintEvent *event);

private:
    QString m_text;
    int m_fntSize;
    QFont m_font;
    QColor m_color;
    QString m_format;
    int m_blink1;
    int m_blink2;

};

#endif // FONTCLOCK_H
